@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (C) 2003 - 2017 Michal Čihař
+ * Copyright (C) 2003 - 2018 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ unsigned char *StringPythonToGammu(PyObject * o)
 		PyErr_Format(PyExc_ValueError, "Can not get unicode value");
 		return NULL;
 	}
-	gs = strPythonToGammu(ps, PyUnicode_GetSize(u));
+	gs = strPythonToGammu(ps, PyUnicode_GET_LENGTH(u));
 	Py_DECREF(u);
 	return gs;
 }
